@@ -5,6 +5,7 @@ import gettext
 import subprocess
 import logging
 import json
+import re
 
 from xapp.GSettingsWidgets import GSettingsSwitch, GSettingsFileChooser, GSettingsComboBox
 from xapp.SettingsWidgets import SettingsWidget, SettingsPage, SettingsStack, SpinButton, Entry, Button, ComboBox
@@ -37,6 +38,7 @@ RPC_THREAD_POOL_SIZE_KEY = "rpc-thread-pool-size"
 USE_COMPRESSION_KEY = "use-compression"
 COMPRESSION_LEVEL_KEY = "zlib-compression-level"
 BLOCK_SIZE_KEY = "transfer-block-size"
+MIN_FREE_SPACE_KEY = "minimum-free-space"
 
 prefs_settings = Gio.Settings(schema_id=PREFS_SCHEMA)
 
@@ -133,6 +135,9 @@ def get_compression_level():
 def get_block_size():
     return prefs_settings.get_int(BLOCK_SIZE_KEY) * 1024
 
+def get_min_free_space():
+    return prefs_settings.get_uint(MIN_FREE_SPACE_KEY)
+
 class Preferences():
     def __init__(self, transient_for):
         self.builder = Gtk.Builder.new_from_file(os.path.join(config.pkgdatadir, "prefs-window.ui"))
@@ -224,6 +229,10 @@ class Preferences():
             lshw_out = subprocess.check_output(["lshw", "-class", "network", "-sanitize", "-json"],
                                                stderr=subprocess.DEVNULL
                                               ).decode("utf-8")
+
+            lshw_out = re.sub("\A\s*{", "[{", lshw_out)
+            lshw_out = re.sub("}\s*{", "}, {", lshw_out)
+            lshw_out = re.sub("}\s*\\n\Z", "}]\n", lshw_out)
             j = json.loads(lshw_out)
         except:
             pass
